defmodule DecentralisedBookIndex.Metadata.AuthorAliasRegistry do
  use Ash.Resource,
    otp_app: :decentralised_book_index,
    domain: DecentralisedBookIndex.Metadata,
    data_layer: AshPostgres.DataLayer

  alias DecentralisedBookIndex.Metadata

  postgres do
    table "author_alias_registries"
    repo DecentralisedBookIndex.Repo
  end

  actions do
    defaults [:read, :create, :update, :destroy]

    create :sync_create do
      accept [:id, :dbi_server_id]
    end

    update :sync do
      accept [:id, :dbi_server_id]
    end

    read :by_id do
      argument :id, :uuid, allow_nil?: false
      get? true
      filter expr(id == ^arg(:id))
    end
  end

  attributes do
    uuid_primary_key :id, writable?: true

    timestamps()
  end

  relationships do
    belongs_to :dbi_server, Metadata.DBIServer

    has_many :authors, DecentralisedBookIndex.Metadata.Author
  end
end
